# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/daily/v1/daily_vwap.proto
# Protobuf Python Version: 5.27.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    0,
    '',
    'systemathics/apis/services/daily/v1/daily_vwap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/daily/v1/daily_vwap.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xd6\x01\n\x11\x44\x61ilyVwapsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x1e\n\nadjustment\x18\x03 \x01(\x08R\nadjustment\"X\n\x12\x44\x61ilyVwapsResponse\x12\x42\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..systemathics.apis.services.daily.v1.DailyVwapR\x04\x64\x61ta\"v\n\tDailyVwap\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05price\x18\x02 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x03 \x01(\x01R\x06volume\x12\x14\n\x05score\x18\x04 \x01(\x01R\x05score2\xac\x01\n\x11\x44\x61ilyVwapsService\x12\x96\x01\n\nDailyVwaps\x12\x36.systemathics.apis.services.daily.v1.DailyVwapsRequest\x1a\x37.systemathics.apis.services.daily.v1.DailyVwapsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/daily/vwapsB\xea\x01\n\'com.systemathics.apis.services.daily.v1B\x0e\x44\x61ilyVwapProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_vwap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\016DailyVwapProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYVWAPSSERVICE'].methods_by_name['DailyVwaps']._loaded_options = None
  _globals['_DAILYVWAPSSERVICE'].methods_by_name['DailyVwaps']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/daily/vwaps'
  _globals['_DAILYVWAPSREQUEST']._serialized_start=253
  _globals['_DAILYVWAPSREQUEST']._serialized_end=467
  _globals['_DAILYVWAPSRESPONSE']._serialized_start=469
  _globals['_DAILYVWAPSRESPONSE']._serialized_end=557
  _globals['_DAILYVWAP']._serialized_start=559
  _globals['_DAILYVWAP']._serialized_end=677
  _globals['_DAILYVWAPSSERVICE']._serialized_start=680
  _globals['_DAILYVWAPSSERVICE']._serialized_end=852
# @@protoc_insertion_point(module_scope)
