# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.daily.v1 import daily_calendars_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2


class DailyCalendarsServiceStub(object):
    """Called to request daily calendars data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DailyCalendars = channel.unary_unary(
                '/systemathics.apis.services.daily.v1.DailyCalendarsService/DailyCalendars',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsResponse.FromString,
                )


class DailyCalendarsServiceServicer(object):
    """Called to request daily calendars data. 
    """

    def DailyCalendars(self, request, context):
        """Gets daily historical calendars
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DailyCalendarsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DailyCalendars': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyCalendars,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v1.DailyCalendarsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DailyCalendarsService(object):
    """Called to request daily calendars data. 
    """

    @staticmethod
    def DailyCalendars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v1.DailyCalendarsService/DailyCalendars',
            systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
